@@ -12,25 +12,34 @@ use regex::Regex;
 use reqwest::blocking::Client;
 use reqwest::Url;
 use sha2::{Digest, Sha256, Sha384, Sha512};
-use std::collections::HashMap;
 use std::default::Default;
 
+use crate::cache::Cache;
+use crate::core::{parse_content_type, retrieve_asset, Options};
 use crate::css::embed_css;
 use crate::js::attr_is_event_handler;
-use crate::opts::Options;
 use crate::url::{
     clean_url, create_data_url, is_url_and_has_protocol, resolve_url, EMPTY_IMAGE_DATA_URL,
 };
-use crate::utils::{parse_content_type, retrieve_asset};
+
+#[derive(PartialEq, Eq)]
+pub enum LinkType {
+    Alternate,
+    AppleTouchIcon,
+    DnsPrefetch,
+    Favicon,
+    Preload,
+    Stylesheet,
+}
 
 struct SrcSetItem<'a> {
     path: &'a str,
     descriptor: &'a str,
 }
 
-const ICON_VALUES: &'static [&str] = &["icon", "shortcut icon"];
+const FAVICON_VALUES: &[&str] = &["icon", "shortcut icon"];
 
-const WHITESPACES: &'static [char] = &['\t', '\n', '\x0c', '\r', ' '];
+const WHITESPACES: &[char] = &['\t', '\n', '\x0c', '\r', ' '];
 
 pub fn add_favicon(document: &Handle, favicon_data_url: String) -> RcDom {
     let mut buf: Vec<u8> = Vec::new();
@@ -131,7 +140,7 @@ pub fn create_metadata_tag(url: &Url) -> String {
     format!(
         "<!-- Saved from {} at {} using {} v{} -->",
         if clean_url.scheme() == "http" || clean_url.scheme() == "https" {
-            &clean_url.as_str()
+            clean_url.as_str()
         } else {
             "local source"
         },
@@ -141,28 +150,8 @@ pub fn create_metadata_tag(url: &Url) -> String {
     )
 }
 
-pub fn determine_link_node_type(node: &Handle) -> &str {
-    let mut link_type: &str = "unknown";
-
-    if let Some(link_attr_rel_value) = get_node_attr(node, "rel") {
-        if is_icon(&link_attr_rel_value) {
-            link_type = "icon";
-        } else if link_attr_rel_value.eq_ignore_ascii_case("stylesheet")
-            || link_attr_rel_value.eq_ignore_ascii_case("alternate stylesheet")
-        {
-            link_type = "stylesheet";
-        } else if link_attr_rel_value.eq_ignore_ascii_case("preload") {
-            link_type = "preload";
-        } else if link_attr_rel_value.eq_ignore_ascii_case("dns-prefetch") {
-            link_type = "dns-prefetch";
-        }
-    }
-
-    link_type
-}
-
 pub fn embed_srcset(
-    cache: &mut HashMap<String, Vec<u8>>,
+    cache: &mut Option<Cache>,
     client: &Client,
     document_url: &Url,
     srcset: &str,
@@ -216,8 +205,8 @@ pub fn embed_srcset(
         if options.no_images {
             result.push_str(EMPTY_IMAGE_DATA_URL);
         } else {
-            let image_full_url: Url = resolve_url(&document_url, part.path);
-            match retrieve_asset(cache, client, &document_url, &image_full_url, options) {
+            let image_full_url: Url = resolve_url(document_url, part.path);
+            match retrieve_asset(cache, client, document_url, &image_full_url, options) {
                 Ok((image_data, image_final_url, image_media_type, image_charset)) => {
                     let mut image_data_url = create_data_url(
                         &image_media_type,
@@ -242,7 +231,7 @@ pub fn embed_srcset(
         }
 
         if !part.descriptor.is_empty() {
-            result.push_str(" ");
+            result.push(' ');
             result.push_str(part.descriptor);
         }
 
@@ -267,11 +256,8 @@ pub fn find_base_node(node: &Handle) -> Option<Handle> {
             }
         }
         NodeData::Element { ref name, .. } => {
-            match name.local.as_ref() {
-                "head" => {
-                    return get_child_node_by_name(node, "base");
-                }
-                _ => {}
+            if name.local.as_ref() == "head" {
+                return get_child_node_by_name(node, "base");
             }
 
             // Dig deeper
@@ -298,22 +284,18 @@ pub fn find_meta_charset_or_content_type_node(node: &Handle) -> Option<Handle> {
             }
         }
         NodeData::Element { ref name, .. } => {
-            match name.local.as_ref() {
-                "head" => {
-                    if let Some(meta_node) = get_child_node_by_name(node, "meta") {
-                        if let Some(_) = get_node_attr(&meta_node, "charset") {
+            if name.local.as_ref() == "head" {
+                if let Some(meta_node) = get_child_node_by_name(node, "meta") {
+                    if get_node_attr(&meta_node, "charset").is_some() {
+                        return Some(meta_node);
+                    } else if let Some(meta_node_http_equiv_attr_value) =
+                        get_node_attr(&meta_node, "http-equiv")
+                    {
+                        if meta_node_http_equiv_attr_value.eq_ignore_ascii_case("content-type") {
                             return Some(meta_node);
-                        } else if let Some(meta_node_http_equiv_attr_value) =
-                            get_node_attr(&meta_node, "http-equiv")
-                        {
-                            if meta_node_http_equiv_attr_value.eq_ignore_ascii_case("content-type")
-                            {
-                                return Some(meta_node);
-                            }
                         }
                     }
                 }
-                _ => {}
             }
 
             // Dig deeper
@@ -352,7 +334,7 @@ pub fn get_charset(node: &Handle) -> Option<String> {
         }
     }
 
-    return None;
+    None
 }
 
 pub fn get_child_node_by_name(parent: &Handle, node_name: &str) -> Option<Handle> {
@@ -361,15 +343,12 @@ pub fn get_child_node_by_name(parent: &Handle, node_name: &str) -> Option<Handle
         NodeData::Element { ref name, .. } => &*name.local == node_name,
         _ => false,
     });
-    match matching_children {
-        Some(node) => Some(node.clone()),
-        _ => None,
-    }
+    matching_children.cloned()
 }
 
 pub fn get_node_attr(node: &Handle, attr_name: &str) -> Option<String> {
     match &node.data {
-        NodeData::Element { ref attrs, .. } => {
+        NodeData::Element { attrs, .. } => {
             for attr in attrs.borrow().iter() {
                 if &*attr.name.local == attr_name {
                     return Some(attr.value.to_string());
@@ -383,7 +362,7 @@ pub fn get_node_attr(node: &Handle, attr_name: &str) -> Option<String> {
 
 pub fn get_node_name(node: &Handle) -> Option<&'_ str> {
     match &node.data {
-        NodeData::Element { ref name, .. } => Some(name.local.as_ref()),
+        NodeData::Element { name, .. } => Some(name.local.as_ref()),
         _ => None,
     }
 }
@@ -407,15 +386,12 @@ pub fn has_favicon(handle: &Handle) -> bool {
             }
         }
         NodeData::Element { ref name, .. } => {
-            match name.local.as_ref() {
-                "link" => {
-                    if let Some(attr_value) = get_node_attr(handle, "rel") {
-                        if is_icon(attr_value.trim()) {
-                            found_favicon = true;
-                        }
+            if name.local.as_ref() == "link" {
+                if let Some(attr_value) = get_node_attr(handle, "rel") {
+                    if is_favicon(attr_value.trim()) {
+                        found_favicon = true;
                     }
                 }
-                _ => {}
             }
 
             if !found_favicon {
@@ -438,10 +414,10 @@ pub fn html_to_dom(data: &Vec<u8>, document_encoding: String) -> RcDom {
     let s: String;
 
     if let Some(encoding) = Encoding::for_label(document_encoding.as_bytes()) {
-        let (string, _, _) = encoding.decode(&data);
+        let (string, _, _) = encoding.decode(data);
         s = string.to_string();
     } else {
-        s = String::from_utf8_lossy(&data).to_string();
+        s = String::from_utf8_lossy(data).to_string();
     }
 
     parse_document(RcDom::default(), Default::default())
@@ -450,8 +426,30 @@ pub fn html_to_dom(data: &Vec<u8>, document_encoding: String) -> RcDom {
         .unwrap()
 }
 
-pub fn is_icon(attr_value: &str) -> bool {
-    ICON_VALUES.contains(&attr_value.to_lowercase().as_str())
+pub fn is_favicon(attr_value: &str) -> bool {
+    FAVICON_VALUES.contains(&attr_value.to_lowercase().as_str())
+}
+
+pub fn parse_link_type(link_attr_rel_value: &str) -> Vec<LinkType> {
+    let mut types: Vec<LinkType> = vec![];
+
+    for link_attr_rel_type in link_attr_rel_value.split_whitespace() {
+        if link_attr_rel_type.eq_ignore_ascii_case("alternate") {
+            types.push(LinkType::Alternate);
+        } else if link_attr_rel_type.eq_ignore_ascii_case("dns-prefetch") {
+            types.push(LinkType::DnsPrefetch);
+        } else if link_attr_rel_type.eq_ignore_ascii_case("preload") {
+            types.push(LinkType::Preload);
+        } else if link_attr_rel_type.eq_ignore_ascii_case("stylesheet") {
+            types.push(LinkType::Stylesheet);
+        } else if is_favicon(link_attr_rel_type) {
+            types.push(LinkType::Favicon);
+        } else if link_attr_rel_type.eq_ignore_ascii_case("apple-touch-icon") {
+            types.push(LinkType::AppleTouchIcon);
+        }
+    }
+
+    types
 }
 
 pub fn set_base_url(document: &Handle, desired_base_href: String) -> RcDom {
@@ -491,9 +489,9 @@ pub fn set_base_url(document: &Handle, desired_base_href: String) -> RcDom {
 
 pub fn set_charset(mut dom: RcDom, desired_charset: String) -> RcDom {
     if let Some(meta_charset_node) = find_meta_charset_or_content_type_node(&dom.document) {
-        if let Some(_) = get_node_attr(&meta_charset_node, "charset") {
+        if get_node_attr(&meta_charset_node, "charset").is_some() {
             set_node_attr(&meta_charset_node, "charset", Some(desired_charset));
-        } else if let Some(_) = get_node_attr(&meta_charset_node, "content") {
+        } else if get_node_attr(&meta_charset_node, "content").is_some() {
             set_node_attr(
                 &meta_charset_node,
                 "content",
@@ -525,42 +523,39 @@ pub fn set_charset(mut dom: RcDom, desired_charset: String) -> RcDom {
 }
 
 pub fn set_node_attr(node: &Handle, attr_name: &str, attr_value: Option<String>) {
-    match &node.data {
-        NodeData::Element { ref attrs, .. } => {
-            let attrs_mut = &mut attrs.borrow_mut();
-            let mut i = 0;
-            let mut found_existing_attr: bool = false;
+    if let NodeData::Element { attrs, .. } = &node.data {
+        let attrs_mut = &mut attrs.borrow_mut();
+        let mut i = 0;
+        let mut found_existing_attr: bool = false;
 
-            while i < attrs_mut.len() {
-                if &attrs_mut[i].name.local == attr_name {
-                    found_existing_attr = true;
+        while i < attrs_mut.len() {
+            if &attrs_mut[i].name.local == attr_name {
+                found_existing_attr = true;
 
-                    if let Some(attr_value) = attr_value.clone() {
-                        let _ = &attrs_mut[i].value.clear();
-                        let _ = &attrs_mut[i].value.push_slice(&attr_value.as_str());
-                    } else {
-                        // Remove attr completely if attr_value is not defined
-                        attrs_mut.remove(i);
-                        continue;
-                    }
+                if let Some(attr_value) = attr_value.clone() {
+                    let _ = &attrs_mut[i].value.clear();
+                    let _ = &attrs_mut[i].value.push_slice(attr_value.as_str());
+                } else {
+                    // Remove attr completely if attr_value is not defined
+                    attrs_mut.remove(i);
+                    continue;
                 }
-
-                i += 1;
             }
 
-            if !found_existing_attr {
-                // Add new attribute (since originally the target node didn't have it)
-                if let Some(attr_value) = attr_value.clone() {
-                    let name = LocalName::from(attr_name);
+            i += 1;
+        }
 
-                    attrs_mut.push(Attribute {
-                        name: QualName::new(None, ns!(), name),
-                        value: format_tendril!("{}", attr_value),
-                    });
-                }
+        if !found_existing_attr {
+            // Add new attribute (since originally the target node didn't have it)
+            if let Some(attr_value) = attr_value.clone() {
+                let name = LocalName::from(attr_name);
+
+                attrs_mut.push(Attribute {
+                    name: QualName::new(None, ns!(), name),
+                    value: format_tendril!("{}", attr_value),
+                });
             }
         }
-        _ => {}
     };
 }
 
@@ -613,7 +608,7 @@ pub fn serialize_document(mut dom: RcDom, document_encoding: String, options: &O
     if options.unwrap_noscript {
         let s: &str = &String::from_utf8_lossy(&buf);
         let noscript_re = Regex::new(r"<(?P<c>/?noscript[^>]*)>").unwrap();
-        buf = noscript_re.replace_all(&s, "<!--$c-->").as_bytes().to_vec();
+        buf = noscript_re.replace_all(s, "<!--$c-->").as_bytes().to_vec();
     }
 
     if !document_encoding.is_empty() {
@@ -628,7 +623,7 @@ pub fn serialize_document(mut dom: RcDom, document_encoding: String, options: &O
 }
 
 pub fn retrieve_and_embed_asset(
-    cache: &mut HashMap<String, Vec<u8>>,
+    cache: &mut Option<Cache>,
     client: &Client,
     document_url: &Url,
     node: &Handle,
@@ -640,7 +635,7 @@ pub fn retrieve_and_embed_asset(
 
     match retrieve_asset(cache, client, &document_url.clone(), &resolved_url, options) {
         Ok((data, final_url, mut media_type, charset)) => {
-            let node_name: &str = get_node_name(&node).unwrap();
+            let node_name: &str = get_node_name(node).unwrap();
 
             // Check integrity if it's a LINK or SCRIPT element
             let mut ok_to_include: bool = true;
@@ -665,18 +660,21 @@ pub fn retrieve_and_embed_asset(
                     s = String::from_utf8_lossy(&data).to_string();
                 }
 
-                if node_name == "link" && determine_link_node_type(node) == "stylesheet" {
+                if node_name == "link"
+                    && parse_link_type(&get_node_attr(node, "rel").unwrap_or(String::from("")))
+                        .contains(&LinkType::Stylesheet)
+                {
                     // Stylesheet LINK elements require special treatment
                     let css: String = embed_css(cache, client, &final_url, &s, options);
 
                     // Create and embed data URL
                     let css_data_url =
                         create_data_url(&media_type, &charset, css.as_bytes(), &final_url);
-                    set_node_attr(&node, attr_name, Some(css_data_url.to_string()));
+                    set_node_attr(node, attr_name, Some(css_data_url.to_string()));
                 } else if node_name == "frame" || node_name == "iframe" {
                     // (I)FRAMEs are also quite different from conventional resources
                     let frame_dom = html_to_dom(&data, charset.clone());
-                    walk_and_embed_assets(cache, client, &final_url, &frame_dom.document, &options);
+                    walk_and_embed_assets(cache, client, &final_url, &frame_dom.document, options);
 
                     let mut frame_data: Vec<u8> = Vec::new();
                     serialize(
@@ -695,14 +693,12 @@ pub fn retrieve_and_embed_asset(
                     // Every other type of element gets processed here
 
                     // Parse media type for SCRIPT elements
-                    if node_name == "script" {
-                        if let Some(_) = get_node_attr(node, "src") {
-                            if let Some(script_node_type_attr_value) = get_node_attr(node, "type") {
-                                media_type = script_node_type_attr_value.to_string();
-                            } else {
-                                // Fallback to default one if it's not specified
-                                media_type = "application/javascript".to_string();
-                            }
+                    if node_name == "script" && get_node_attr(node, "src").is_some() {
+                        if let Some(script_node_type_attr_value) = get_node_attr(node, "type") {
+                            media_type = script_node_type_attr_value.to_string();
+                        } else {
+                            // Fallback to default one if it's not specified
+                            media_type = "application/javascript".to_string();
                         }
                     }
 
@@ -726,7 +722,7 @@ pub fn retrieve_and_embed_asset(
 }
 
 pub fn walk_and_embed_assets(
-    cache: &mut HashMap<String, Vec<u8>>,
+    cache: &mut Option<Cache>,
     client: &Client,
     document_url: &Url,
     node: &Handle,
@@ -736,7 +732,7 @@ pub fn walk_and_embed_assets(
         NodeData::Document => {
             // Dig deeper
             for child in node.children.borrow().iter() {
-                walk_and_embed_assets(cache, client, &document_url, child, options);
+                walk_and_embed_assets(cache, client, document_url, child, options);
             }
         }
         NodeData::Element {
@@ -752,21 +748,24 @@ pub fn walk_and_embed_assets(
                             || meta_attr_http_equiv_value.eq_ignore_ascii_case("location")
                         {
                             // Remove http-equiv attributes from META nodes if they're able to control the page
-                            set_node_attr(&node, "http-equiv", None);
+                            set_node_attr(node, "http-equiv", None);
                         }
                     }
                 }
                 "link" => {
-                    let link_type: &str = determine_link_node_type(node);
+                    let link_node_types: Vec<LinkType> =
+                        parse_link_type(&get_node_attr(node, "rel").unwrap_or(String::from("")));
 
-                    if link_type == "icon" {
+                    if link_node_types.contains(&LinkType::Favicon)
+                        || link_node_types.contains(&LinkType::AppleTouchIcon)
+                    {
                         // Find and resolve LINK's href attribute
                         if let Some(link_attr_href_value) = get_node_attr(node, "href") {
                             if !options.no_images && !link_attr_href_value.is_empty() {
                                 retrieve_and_embed_asset(
                                     cache,
                                     client,
-                                    &document_url,
+                                    document_url,
                                     node,
                                     "href",
                                     &link_attr_href_value,
@@ -776,35 +775,35 @@ pub fn walk_and_embed_assets(
                                 set_node_attr(node, "href", None);
                             }
                         }
-                    } else if link_type == "stylesheet" {
+                    } else if link_node_types.contains(&LinkType::Stylesheet) {
                         // Resolve LINK's href attribute
                         if let Some(link_attr_href_value) = get_node_attr(node, "href") {
                             if options.no_css {
                                 set_node_attr(node, "href", None);
                                 // Wipe integrity attribute
                                 set_node_attr(node, "integrity", None);
-                            } else {
-                                if !link_attr_href_value.is_empty() {
-                                    retrieve_and_embed_asset(
-                                        cache,
-                                        client,
-                                        &document_url,
-                                        node,
-                                        "href",
-                                        &link_attr_href_value,
-                                        options,
-                                    );
-                                }
+                            } else if !link_attr_href_value.is_empty() {
+                                retrieve_and_embed_asset(
+                                    cache,
+                                    client,
+                                    document_url,
+                                    node,
+                                    "href",
+                                    &link_attr_href_value,
+                                    options,
+                                );
                             }
                         }
-                    } else if link_type == "preload" || link_type == "dns-prefetch" {
+                    } else if link_node_types.contains(&LinkType::Preload)
+                        || link_node_types.contains(&LinkType::DnsPrefetch)
+                    {
                         // Since all resources are embedded as data URLs, preloading and prefetching are not necessary
                         set_node_attr(node, "rel", None);
                     } else {
                         // Make sure that all other LINKs' href attributes are full URLs
                         if let Some(link_attr_href_value) = get_node_attr(node, "href") {
                             let href_full_url: Url =
-                                resolve_url(&document_url, &link_attr_href_value);
+                                resolve_url(document_url, &link_attr_href_value);
                             set_node_attr(node, "href", Some(href_full_url.to_string()));
                         }
                     }
@@ -845,49 +844,47 @@ pub fn walk_and_embed_assets(
 
                     if options.no_images {
                         // Put empty images into src and data-src attributes
-                        if img_attr_src_value != None {
+                        if img_attr_src_value.is_some() {
                             set_node_attr(node, "src", Some(EMPTY_IMAGE_DATA_URL.to_string()));
                         }
-                        if img_attr_data_src_value != None {
+                        if img_attr_data_src_value.is_some() {
                             set_node_attr(node, "data-src", Some(EMPTY_IMAGE_DATA_URL.to_string()));
                         }
+                    } else if img_attr_src_value.clone().unwrap_or_default().is_empty()
+                        && img_attr_data_src_value
+                            .clone()
+                            .unwrap_or_default()
+                            .is_empty()
+                    {
+                        // Add empty src attribute
+                        set_node_attr(node, "src", Some("".to_string()));
                     } else {
-                        if img_attr_src_value.clone().unwrap_or_default().is_empty()
-                            && img_attr_data_src_value
-                                .clone()
-                                .unwrap_or_default()
-                                .is_empty()
+                        // Add data URL src attribute
+                        let img_full_url: String = if !img_attr_data_src_value
+                            .clone()
+                            .unwrap_or_default()
+                            .is_empty()
                         {
-                            // Add empty src attribute
-                            set_node_attr(node, "src", Some("".to_string()));
+                            img_attr_data_src_value.unwrap_or_default()
                         } else {
-                            // Add data URL src attribute
-                            let img_full_url: String = if !img_attr_data_src_value
-                                .clone()
-                                .unwrap_or_default()
-                                .is_empty()
-                            {
-                                img_attr_data_src_value.unwrap_or_default()
-                            } else {
-                                img_attr_src_value.unwrap_or_default()
-                            };
-                            retrieve_and_embed_asset(
-                                cache,
-                                client,
-                                document_url,
-                                node,
-                                "src",
-                                &img_full_url,
-                                options,
-                            );
-                        }
+                            img_attr_src_value.unwrap_or_default()
+                        };
+                        retrieve_and_embed_asset(
+                            cache,
+                            client,
+                            document_url,
+                            node,
+                            "src",
+                            &img_full_url,
+                            options,
+                        );
                     }
 
                     // Resolve srcset attribute
                     if let Some(img_srcset) = get_node_attr(node, "srcset") {
                         if !img_srcset.is_empty() {
                             let resolved_srcset: String =
-                                embed_srcset(cache, client, &document_url, &img_srcset, options);
+                                embed_srcset(cache, client, document_url, &img_srcset, options);
                             set_node_attr(node, "srcset", Some(resolved_srcset));
                         }
                     }
@@ -923,34 +920,38 @@ pub fn walk_and_embed_assets(
                         }
                     }
                 }
-                "image" => {
-                    let mut image_href: String = "".to_string();
-
+                "image" | "use" => {
                     if let Some(image_attr_href_value) = get_node_attr(node, "href") {
-                        image_href = image_attr_href_value;
                         if options.no_images {
                             set_node_attr(node, "href", None);
+                        } else {
+                            retrieve_and_embed_asset(
+                                cache,
+                                client,
+                                document_url,
+                                node,
+                                "href",
+                                &image_attr_href_value,
+                                options,
+                            );
                         }
                     }
 
                     if let Some(image_attr_xlink_href_value) = get_node_attr(node, "xlink:href") {
-                        image_href = image_attr_xlink_href_value;
                         if options.no_images {
                             set_node_attr(node, "xlink:href", None);
+                        } else {
+                            retrieve_and_embed_asset(
+                                cache,
+                                client,
+                                document_url,
+                                node,
+                                "xlink:href",
+                                &image_attr_xlink_href_value,
+                                options,
+                            );
                         }
                     }
-
-                    if !options.no_images && !image_href.is_empty() {
-                        retrieve_and_embed_asset(
-                            cache,
-                            client,
-                            document_url,
-                            node,
-                            "href",
-                            &image_href,
-                            options,
-                        );
-                    }
                 }
                 "source" => {
                     let parent_node = get_parent_node(node);
@@ -989,24 +990,22 @@ pub fn walk_and_embed_assets(
                     }
 
                     if let Some(source_attr_srcset_value) = get_node_attr(node, "srcset") {
-                        if parent_node_name == "picture" {
-                            if !source_attr_srcset_value.is_empty() {
-                                if options.no_images {
-                                    set_node_attr(
-                                        node,
-                                        "srcset",
-                                        Some(EMPTY_IMAGE_DATA_URL.to_string()),
-                                    );
-                                } else {
-                                    let resolved_srcset: String = embed_srcset(
-                                        cache,
-                                        client,
-                                        &document_url,
-                                        &source_attr_srcset_value,
-                                        options,
-                                    );
-                                    set_node_attr(node, "srcset", Some(resolved_srcset));
-                                }
+                        if parent_node_name == "picture" && !source_attr_srcset_value.is_empty() {
+                            if options.no_images {
+                                set_node_attr(
+                                    node,
+                                    "srcset",
+                                    Some(EMPTY_IMAGE_DATA_URL.to_string()),
+                                );
+                            } else {
+                                let resolved_srcset: String = embed_srcset(
+                                    cache,
+                                    client,
+                                    document_url,
+                                    &source_attr_srcset_value,
+                                    options,
+                                );
+                                set_node_attr(node, "srcset", Some(resolved_srcset));
                             }
                         }
                     }
@@ -1042,7 +1041,7 @@ pub fn walk_and_embed_assets(
                         // Empty inner content
                         node.children.borrow_mut().clear();
                         // Remove src attribute
-                        if script_attr_src != None {
+                        if script_attr_src.is_some() {
                             set_node_attr(node, "src", None);
                             // Wipe integrity attribute
                             set_node_attr(node, "integrity", None);
@@ -1070,7 +1069,7 @@ pub fn walk_and_embed_assets(
                                 let replacement = embed_css(
                                     cache,
                                     client,
-                                    &document_url,
+                                    document_url,
                                     tendril.as_ref(),
                                     options,
                                 );
@@ -1099,7 +1098,7 @@ pub fn walk_and_embed_assets(
                                 retrieve_and_embed_asset(
                                     cache,
                                     client,
-                                    &document_url,
+                                    document_url,
                                     node,
                                     "src",
                                     &frame_attr_src_value,
@@ -1171,43 +1170,38 @@ pub fn walk_and_embed_assets(
                 }
                 "noscript" => {
                     for child_node in node.children.borrow_mut().iter_mut() {
-                        match child_node.data {
-                            NodeData::Text { ref contents } => {
-                                // Get contents of NOSCRIPT node
-                                let mut noscript_contents = contents.borrow_mut();
-                                // Parse contents of NOSCRIPT node as DOM
-                                let noscript_contents_dom: RcDom = html_to_dom(
-                                    &noscript_contents.as_bytes().to_vec(),
-                                    "".to_string(),
-                                );
-                                // Embed assets of NOSCRIPT node contents
-                                walk_and_embed_assets(
-                                    cache,
-                                    client,
-                                    &document_url,
-                                    &noscript_contents_dom.document,
-                                    &options,
-                                );
-                                // Get rid of original contents
-                                noscript_contents.clear();
-                                // Insert HTML containing embedded assets into NOSCRIPT node
-                                if let Some(html) =
-                                    get_child_node_by_name(&noscript_contents_dom.document, "html")
-                                {
-                                    if let Some(body) = get_child_node_by_name(&html, "body") {
-                                        let mut buf: Vec<u8> = Vec::new();
-                                        serialize(
-                                            &mut buf,
-                                            &SerializableHandle::from(body.clone()),
-                                            SerializeOpts::default(),
-                                        )
-                                        .expect("Unable to serialize DOM into buffer");
-                                        let result = String::from_utf8_lossy(&buf);
-                                        noscript_contents.push_slice(&result);
-                                    }
+                        if let NodeData::Text { ref contents } = child_node.data {
+                            // Get contents of NOSCRIPT node
+                            let mut noscript_contents = contents.borrow_mut();
+                            // Parse contents of NOSCRIPT node as DOM
+                            let noscript_contents_dom: RcDom =
+                                html_to_dom(&noscript_contents.as_bytes().to_vec(), "".to_string());
+                            // Embed assets of NOSCRIPT node contents
+                            walk_and_embed_assets(
+                                cache,
+                                client,
+                                document_url,
+                                &noscript_contents_dom.document,
+                                options,
+                            );
+                            // Get rid of original contents
+                            noscript_contents.clear();
+                            // Insert HTML containing embedded assets into NOSCRIPT node
+                            if let Some(html) =
+                                get_child_node_by_name(&noscript_contents_dom.document, "html")
+                            {
+                                if let Some(body) = get_child_node_by_name(&html, "body") {
+                                    let mut buf: Vec<u8> = Vec::new();
+                                    serialize(
+                                        &mut buf,
+                                        &SerializableHandle::from(body.clone()),
+                                        SerializeOpts::default(),
+                                    )
+                                    .expect("Unable to serialize DOM into buffer");
+                                    let result = String::from_utf8_lossy(&buf);
+                                    noscript_contents.push_slice(&result);
                                 }
                             }
-                            _ => {}
                         }
                     }
                 }
@@ -1221,13 +1215,8 @@ pub fn walk_and_embed_assets(
             } else {
                 // Embed URLs found within the style attribute of this node
                 if let Some(node_attr_style_value) = get_node_attr(node, "style") {
-                    let embedded_style = embed_css(
-                        cache,
-                        client,
-                        &document_url,
-                        &node_attr_style_value,
-                        options,
-                    );
+                    let embedded_style =
+                        embed_css(cache, client, document_url, &node_attr_style_value, options);
                     set_node_attr(node, "style", Some(embedded_style));
                 }
             }
@@ -1250,7 +1239,7 @@ pub fn walk_and_embed_assets(
 
             // Dig deeper
             for child in node.children.borrow().iter() {
-                walk_and_embed_assets(cache, client, &document_url, child, options);
+                walk_and_embed_assets(cache, client, document_url, child, options);
             }
         }
         _ => {
