@@ -41,8 +41,8 @@ mod passing {
                 "\
                 {file}{cwd}/tests/_data_/basic/local-file.html\n\
                 {file}{cwd}/tests/_data_/basic/local-style.css\n\
-                {file}{cwd}/tests/_data_/basic/local-style-does-not-exist.css (not found)\n\
-                {file}{cwd}/tests/_data_/basic/monolith.png (not found)\n\
+                {file}{cwd}/tests/_data_/basic/local-style-does-not-exist.css (file not found)\n\
+                {file}{cwd}/tests/_data_/basic/monolith.png (file not found)\n\
                 {file}{cwd}/tests/_data_/basic/local-script.js\n\
                 ",
                 file = file_url_protocol,
@@ -88,7 +88,7 @@ mod passing {
             String::from_utf8_lossy(&out.stderr),
             format!(
                 "{file_url_html}\n",
-                file_url_html = Url::from_file_path(fs::canonicalize(&path_html).unwrap()).unwrap(),
+                file_url_html = Url::from_file_path(fs::canonicalize(path_html).unwrap()).unwrap(),
             )
         );
 
@@ -188,8 +188,8 @@ mod passing {
                 {file_url_html}\n\
                 {file_url_svg}\n\
                 ",
-                file_url_html = Url::from_file_path(fs::canonicalize(&path_html).unwrap()).unwrap(),
-                file_url_svg = Url::from_file_path(fs::canonicalize(&path_svg).unwrap()).unwrap(),
+                file_url_html = Url::from_file_path(fs::canonicalize(path_html).unwrap()).unwrap(),
+                file_url_svg = Url::from_file_path(fs::canonicalize(path_svg).unwrap()).unwrap(),
             )
         );
 
