@@ -9,15 +9,15 @@
 mod passing {
     use reqwest::blocking::Client;
     use reqwest::Url;
-    use std::collections::HashMap;
 
+    use monolith::cache::Cache;
+    use monolith::core::Options;
     use monolith::html;
-    use monolith::opts::Options;
     use monolith::url::EMPTY_IMAGE_DATA_URL;
 
     #[test]
     fn small_medium_large() {
-        let cache = &mut HashMap::new();
+        let cache = &mut Some(Cache::new(0, None));
         let client = Client::new();
         let srcset_value = "small.png 1x, medium.png 1.5x, large.png 2x";
         let mut options = Options::default();
@@ -27,7 +27,7 @@ mod passing {
             cache,
             &client,
             &Url::parse("data:,").unwrap(),
-            &srcset_value,
+            srcset_value,
             &options,
         );
 
@@ -42,7 +42,7 @@ mod passing {
 
     #[test]
     fn small_medium_only_medium_has_scale() {
-        let cache = &mut HashMap::new();
+        let cache = &mut Some(Cache::new(0, None));
         let client = Client::new();
         let srcset_value = "small.png, medium.png 1.5x";
         let mut options = Options::default();
@@ -52,7 +52,7 @@ mod passing {
             cache,
             &client,
             &Url::parse("data:,").unwrap(),
-            &srcset_value,
+            srcset_value,
             &options,
         );
 
@@ -64,7 +64,7 @@ mod passing {
 
     #[test]
     fn commas_within_file_names() {
-        let cache = &mut HashMap::new();
+        let cache = &mut Some(Cache::new(0, None));
         let client = Client::new();
         let srcset_value = "small,s.png 1x, large,l.png 2x";
         let mut options = Options::default();
@@ -74,7 +74,7 @@ mod passing {
             cache,
             &client,
             &Url::parse("data:,").unwrap(),
-            &srcset_value,
+            srcset_value,
             &options,
         );
 
@@ -86,7 +86,7 @@ mod passing {
 
     #[test]
     fn tabs_and_newlines_after_commas() {
-        let cache = &mut HashMap::new();
+        let cache = &mut Some(Cache::new(0, None));
         let client = Client::new();
         let srcset_value = "small,s.png 1x,\nmedium,m.png 2x,\nlarge,l.png 3x";
         let mut options = Options::default();
@@ -96,7 +96,7 @@ mod passing {
             cache,
             &client,
             &Url::parse("data:,").unwrap(),
-            &srcset_value,
+            srcset_value,
             &options,
         );
 
@@ -111,7 +111,7 @@ mod passing {
 
     #[test]
     fn no_whitespace_after_commas() {
-        let cache = &mut HashMap::new();
+        let cache = &mut Some(Cache::new(0, None));
         let client = Client::new();
         let srcset_value = "small,s.png 1x,medium,m.png 2x,large,l.png 3x";
         let mut options = Options::default();
@@ -121,7 +121,7 @@ mod passing {
             cache,
             &client,
             &Url::parse("data:,").unwrap(),
-            &srcset_value,
+            srcset_value,
             &options,
         );
 
@@ -136,7 +136,7 @@ mod passing {
 
     #[test]
     fn last_without_descriptor() {
-        let cache = &mut HashMap::new();
+        let cache = &mut Some(Cache::new(0, None));
         let client = Client::new();
         let srcset_value = "small,s.png 1x, medium,m.png 2x, large,l.png";
         let mut options = Options::default();
@@ -146,7 +146,7 @@ mod passing {
             cache,
             &client,
             &Url::parse("data:,").unwrap(),
-            &srcset_value,
+            srcset_value,
             &options,
         );
 
@@ -171,15 +171,15 @@ mod passing {
 mod failing {
     use reqwest::blocking::Client;
     use reqwest::Url;
-    use std::collections::HashMap;
 
+    use monolith::cache::Cache;
+    use monolith::core::Options;
     use monolith::html;
-    use monolith::opts::Options;
     use monolith::url::EMPTY_IMAGE_DATA_URL;
 
     #[test]
     fn trailing_comma() {
-        let cache = &mut HashMap::new();
+        let cache = &mut Some(Cache::new(0, None));
         let client = Client::new();
         let srcset_value = "small.png 1x, large.png 2x,";
         let mut options = Options::default();
@@ -189,7 +189,7 @@ mod failing {
             cache,
             &client,
             &Url::parse("data:,").unwrap(),
-            &srcset_value,
+            srcset_value,
             &options,
         );
 
